# Copyright 2019 The FastEstimator Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================
from fastestimator.op.tensorop import augmentation, gradient, loss, model
from fastestimator.op.tensorop.argmax import Argmax
from fastestimator.op.tensorop.average import Average
from fastestimator.op.tensorop.gather import Gather
from fastestimator.op.tensorop.reshape import Reshape
from fastestimator.op.tensorop.tensorop import LambdaOp, TensorOp
from fastestimator.op.tensorop.un_hadamard import UnHadamard
